import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ActionableTag from './Actionable';
import StandardTag from './Standard';
var ACTIONABLE_ONLY_PROPS = ['href', 'iconPlacement', 'target', 'actionable', 'linkFactory'];
var STANDARD_ONLY_PROPS = ['closeIcon', 'onClose'];
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small'
};
/**
 * returns key:value in obj except for those keys defined in props
 * @param {Object} obj
 * @param {Array.<string>} props
 * @return {Object}
 */

var filterKeys = function filterKeys(obj, listOfProps) {
  return Object.keys(obj).reduce(function (acc, key) {
    if (listOfProps.indexOf(key) === -1) {
      acc[key] = obj[key];
    }

    return acc;
  }, {});
};

var AtomTag = function AtomTag(props) {
  var href = props.href,
      icon = props.icon,
      onClick = props.onClick,
      size = props.size,
      responsive = props.responsive,
      type = props.type;
  var isActionable = onClick || href;
  var classNames = cx('sui-AtomTag', "sui-AtomTag-" + size, type && "sui-AtomTag--" + type, responsive && 'sui-AtomTag--responsive', icon && 'sui-AtomTag-hasIcon');
  /**
   * Removes all actionable tag props from the react props
   * @return {Object}
   */

  var getStandardProps = function getStandardProps() {
    return filterKeys(props, ACTIONABLE_ONLY_PROPS);
  };
  /**
   * Removes all standard tag props from the react props
   * @return {Object}
   */


  var getActionableProps = function getActionableProps() {
    return filterKeys(props, STANDARD_ONLY_PROPS);
  };

  return isActionable ? React.createElement(ActionableTag, Object.assign({}, getActionableProps(), {
    className: classNames
  })) : React.createElement(StandardTag, Object.assign({}, getStandardProps(), {
    className: classNames
  }));
};

AtomTag.displayName = 'AtomTag';
AtomTag.defaultProps = {
  iconPlacement: 'left'
};
AtomTag.defaultProps = {
  size: SIZES.MEDIUM
};
export default AtomTag;
export { SIZES as atomTagSizes };